(simtelarray)=

# sim_telarray

Support modules for running sim_telarray.

## simtel_config_reader

(simtel-config-reader-1)=

```{eval-rst}
.. automodule:: simtel.simtel_config_reader
   :members:
```

## simtel_config_writer

(simtel-config-writer-1)=

```{eval-rst}
.. automodule:: simtel.simtel_config_writer
   :members:
```

## simtel_table_reader

(simtel-table-reader-1)=

```{eval-rst}
.. automodule:: simtel.simtel_table_reader
   :members:
```

## simtel_io_events

(simtel-io-events-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_events
   :members:
```

## simtel_io_histogram

(simtel-io-histogram-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_histogram
   :members:
```

## simtel_io_histograms

(simtel-io-histograms-1)=

```{eval-rst}
.. automodule:: simtel.simtel_io_histograms
   :members:
```

## simulator_array

(simulate-array-1)=

```{eval-rst}
.. automodule:: simtel.simulator_array
   :members:
```

## simulator_camera_efficiency

(simulate-camera-efficiency-1)=

```{eval-rst}
.. automodule:: simtel.simulator_camera_efficiency
   :members:
```

## simulator_light_emission

(simulate-light-1)=

```{eval-rst}
.. automodule:: simtel.simulator_light_emission
   :members:
```

## simulator_ray_tracing

(simulate-ray-tracing-1)=

```{eval-rst}
.. automodule:: simtel.simulator_ray_tracing
   :members:
```
